@@ -20,8 +20,12 @@ dataframeToD3 <- function(df) {
   if (!is.data.frame(df)) {
     stop("timevis: the input must be a dataframe", call. = FALSE)
   }
+  df <- as.data.frame(df)
   row.names(df) <- NULL
-  apply(df, 1, function(row) as.list(row[!is.na(row)]))
+  lapply(seq_len(nrow(df)), function(row) {
+    row <- df[row, , drop = FALSE]
+    lapply(row[, !is.na(row), drop = FALSE], as.character)
+  })
 }
 
 #' @importFrom magrittr %>%
